==> core-react-0.8.0.tgz: package/es/Dropdown/Dropdown.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import controlledPropValidator from '../_utils/propValidator/controlled';
import Popover from '../Popover';
import DropdownMenu from './DropdownMenu';
import DropdownToggle from './DropdownToggle';

var Dropdown = /*#__PURE__*/function (_Component) {
  _inherits(Dropdown, _Component);

  function Dropdown(props) {
    var _this;

    _classCallCheck(this, Dropdown);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Dropdown).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleToggle", function (open) {
      _this.setState({
        open: open
      });

      _this.props.onToggle && _this.props.onToggle(open);
    });

    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Dropdown, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
    /**
     * @public
     * @name this.refs.dropdown.open
     * @description 展开
     */

  }, {
    key: "open",
    value: function open() {
      this.setState({
        open: true
      });
    }
    /**
     * @public
     * @name this.refs.dropdown.close
     * @description 收起
     */

  }, {
    key: "close",
    value: function close() {
      this.setState({
        open: false
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          disabled = _this$props.disabled,
          aligned = _this$props.aligned;
      var open = this.state.open;
      var toggle, menu;
      React.Children.forEach(children, function (child) {
        if (child.type === DropdownToggle) {
          toggle = child;
        } else if (child.type === DropdownMenu) {
          menu = child;
        }
      });

      var _menu$props = menu.props,
          right = _menu$props.right,
          menuProps = _objectWithoutProperties(_menu$props, ["right"]);

      if (right) {
        menuProps.align = 'right';
      }

      return React.createElement(Popover, _extends({
        triggerMode: "click",
        open: open,
        onToggle: this.handleToggle,
        content: menuProps.children,
        disabled: disabled,
        aligned: aligned
      }, menuProps), React.cloneElement(toggle, {
        open: open
      }));
    }
  }]);

  return Dropdown;
}(Component);

Dropdown.propTypes = {
  children: PropTypes.node,

  /** 是否展开 */
  // TODO need to add more details in props table
  open: controlledPropValidator(PropTypes.bool, 'onToggle'),

  /** 切换 open 状态后的回调，参数为切换后的 open 状态 */
  onToggle: PropTypes.func,

  /** 是否禁用 */
  disabled: PropTypes.bool,

  /** DropdownToggle 与 DropdownMenu 宽度相同 */
  aligned: PropTypes.bool
};
export default Dropdown;

==> core-react-0.8.2.tgz: package/es/Dropdown/Dropdown.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import controlledPropValidator from '../_utils/propValidator/controlled';
import Popover from '../Popover';
import DropdownMenu from './DropdownMenu';
import DropdownToggle from './DropdownToggle';

var Dropdown = /*#__PURE__*/function (_Component) {
  _inherits(Dropdown, _Component);

  function Dropdown(props) {
    var _this;

    _classCallCheck(this, Dropdown);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Dropdown).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleToggle", function (open) {
      _this.setState({
        open: open
      });

      _this.props.onToggle && _this.props.onToggle(open);
    });

    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Dropdown, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
    /**
     * @public
     * @name this.refs.dropdown.open
     * @description 展开
     */

  }, {
    key: "open",
    value: function open() {
      this.setState({
        open: true
      });
    }
    /**
     * @public
     * @name this.refs.dropdown.close
     * @description 收起
     */

  }, {
    key: "close",
    value: function close() {
      this.setState({
        open: false
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          disabled = _this$props.disabled,
          aligned = _this$props.aligned;
      var open = this.state.open;
      var toggle, menu;
      React.Children.forEach(children, function (child) {
        if (child.type === DropdownToggle) {
          toggle = child;
        } else if (child.type === DropdownMenu) {
          menu = child;
        }
      });

      var _menu$props = menu.props,
          right = _menu$props.right,
          menuProps = _objectWithoutProperties(_menu$props, ["right"]);

      if (right) {
        menuProps.align = 'right';
      }

      return (/*#__PURE__*/React.createElement(Popover, _extends({
          triggerMode: "click",
          open: open,
          onToggle: this.handleToggle,
          content: menuProps.children,
          disabled: disabled,
          aligned: aligned
        }, menuProps), React.cloneElement(toggle, {
          open: open
        }))
      );
    }
  }]);

  return Dropdown;
}(Component);

Dropdown.propTypes = {
  children: PropTypes.node,

  /** 是否展开 */
  // TODO need to add more details in props table
  open: controlledPropValidator(PropTypes.bool, 'onToggle'),

  /** 切换 open 状态后的回调，参数为切换后的 open 状态 */
  onToggle: PropTypes.func,

  /** 是否禁用 */
  disabled: PropTypes.bool,

  /** DropdownToggle 与 DropdownMenu 宽度相同 */
  aligned: PropTypes.bool
};
export default Dropdown;
